## 1.3.0 (stable)

- **NEW** and **FIX**: `set_default_font()` function now fetches and adds all font variants (weight, style) ([issue #23](https://github.com/y-sunflower/pyfonts/issues/23), [PR #39](https://github.com/y-sunflower/pyfonts/pull/39))

## 1.3.0

- **NEW**: Add `load_bunny_font()` function to use fonts from Bunny Fonts ([issue #32](https://github.com/y-sunflower/pyfonts/issues/32), [PR #37](https://github.com/y-sunflower/pyfonts/pull/37))
- **DOC**: New landing page ([PR #36](https://github.com/y-sunflower/pyfonts/pull/36))
- **FIX**: Fix path VS url detection ([issue #34](https://github.com/y-sunflower/pyfonts/issues/34), [PR #35](https://github.com/y-sunflower/pyfonts/pull/35))

## 1.1.3

This changelog page has been created when `pyfonts` 1.1.3 was released.
